@@ -1,7 +1,6 @@
 import logging
 
-from django.db.models import JSONField
-
+from isc_common.fields.code_field import JSONFieldIVC
 from isc_common.fields.related import ForeignKeyCascade
 from isc_common.models.audit import AuditModel
 
@@ -11,7 +10,7 @@ logger = logging.getLogger(__name__)
 class User_permission(AuditModel):
     user = ForeignKeyCascade("User")
     widget = ForeignKeyCascade("Widgets_trees")
-    permission = JSONField(default=dict)
+    permission = JSONFieldIVC(default=dict)
 
     def __str__(self):
         return f"{self.user.username}: {self.widget.id_widget}"
