@@ -1,3 +1,4 @@
+from django.contrib.postgres.fields import JSONField
 from django.db.models import CharField
 from isc_common.fields import Field
 
@@ -46,3 +47,5 @@ class ColorField(CharField, Field):
         del kwargs['default']
         return name, path, args, kwargs
 
+class JSONFieldIVC (JSONField):
+    pass
