@@ -159,6 +159,20 @@ class DSRequest(RPCRequest):
             res = dict((key, value) for (key, value) in res.items() if not key.startswith('_') and key not in excluded_keys)
         return res
 
+    def get_old_data(self, excluded_keys=['grid']):
+        res = None
+        if isinstance(self.json, dict):
+            data = self.json.get('oldValues')
+            if isinstance(data, dict):
+                res = data
+            elif isinstance(data, str):
+                return data
+            else:
+                res = self.json
+
+            res = dict((key, value) for (key, value) in res.items() if not key.startswith('_') and key not in excluded_keys)
+        return res
+
     def get_all_data(self, excluded_keys=['grid']):
         res = None
         if isinstance(self.json, dict):
