@@ -835,7 +835,7 @@ class CommonManager(Manager):
     def deleteFromRequest(self, request, removed=None, ):
         request = DSRequest(request=request)
         res = 0
-        tuple_ids = request.get_tuple_ids()
+        tuple_ids = request.get_olds_tuple_ids()
         with transaction.atomic():
             for id, mode in tuple_ids:
                 if mode == 'hide':
