@@ -57,6 +57,16 @@ def IntToNumber(s):
     return float(s)
 
 
+def ToStr(s):
+    if s == None or s == 'null':
+        return None
+
+    if not isinstance(s, str):
+        return str(s)
+
+    return s
+
+
 def ToNumber(s):
     if s == None:
         return 0
@@ -171,9 +181,11 @@ def compare_2_dict(dict1, dict2):
             messages.append(f'{x_values} != {y_values}')
     return messages
 
+
 def flen(iterable):
     return reduce(lambda sum, element: sum + 1, iterable, 0)
 
+
 class Set:
     _lst = []
     _set = set()
