@@ -14,7 +14,14 @@ def get_NullStr(str):
         return str
 
 def StrToBytes(mystring):
- return mystring.encode('utf-8')
+    if isinstance(mystring, str):
+        return mystring.encode('utf-8')
+    else:
+        raise Exception(f'{mystring} must be str')
+
 
 def BytesToStr(mybytes):
- return mybytes.decode('utf-8')
+    if isinstance(mybytes, bytes):
+        return mybytes.decode('utf-8')
+    else:
+        raise Exception(f'{mybytes} must be bytes')
